package jamessoft.dummy.data;

import anywheresoftware.b4a.BA.Author;
import anywheresoftware.b4a.BA.ShortName;
import anywheresoftware.b4a.BA.Version;
import anywheresoftware.b4a.objects.collections.List;
import jamessoft.dummy.data.*;

@Version(1.0f)
@ShortName("DummyData")
@Author("Jaames") 
public class DummyData {
	public static int SORT_ASCENDING = 1;
	public static int SORT_DESCENDING = 2;
	public static int SORT_NONE = 3;
	private ddFirstNames firstNames;
	private ddLastNames lastNames;
	private ddCompanyNames companies;
	private ddAddresses addresses;
	private ddCities cities;
	private ddCountries countries;
	private ddPostal postal;
	private ddPhones1 phones1;
	private ddPhones2 phones2;
	private ddEmails emails;
	private ddWebs webs;

	/**
	 * returns all the data from selected "Table" - Field
	 * You can select which field you want by passing one of the string parameters: 
	 * <b>FirstNames </b><b>LastNames </b><b>Companies </b><b>Addresses </b><b>Cities </b>
	 * <b>Countries </b><b>Postal </b><b>Phones1 </b><b>Phones2 </b><b>Emails </b><b>Webs </b>
	 * And you can sort the data by passing one of the SortingMode parameters:
	 * <b>SORT_ASCENDING</b> - will sort the data in ascending order
	 * <b>SORT_DESCENDING</b> - will sort the data in descending order
	 * <b>SORT_NONE</b> - will return unsorted data
	 * Example:
	 * <code>Dim Data as DummyData
	 * Dim l As List = Data.GetDummyData("FirstNames", Data.SORT_ASCENDING)
	 * For x = 0 To Data.Size -1
	 *     Log(Data.Get(x))
	 * Next</code>
	 * You can access the fields also individually
	 */		
	public List GetDummyData(String Data, int SortingMode){
		switch (Data) {
		case "FirstNames":
			return GetFirstNames(SortingMode);
		case "LastNames":
			return GetLastNames(SortingMode);	
		case "Companies":
			return GetCompanies(SortingMode);	
		case "Addresses":
			return GetAddresses(SortingMode);	
		case "Cities":
			return GetCities(SortingMode);		
		case "Countries":
			return GetCountries(SortingMode);		
		case "Postal":
			return GetPostal(SortingMode);	
		case "Phones1":
			return GetPhones1(SortingMode);		
		case "Phones2":
			return GetPhones2(SortingMode);		
		case "Emails":
			return GetEmails(SortingMode);
		case "Webs":
			return GetWebs(SortingMode);				
		default:
			return GetFirstNames(SortingMode);
		}
		
	}
	
	/**
	 * returns all the data <b>First Names</b> sorted by the given SortingMode parameter 
	 * <b>SORT_ASCENDING</b> - will sort the data in ascending order
	 * <b>SORT_DESCENDING</b> - will sort the data in descending order
	 * <b>SORT_NONE</b> - will return unsorted data
	 */
	public List GetFirstNames(int SortingMode){
		firstNames = new ddFirstNames();
		return firstNames.GetAll(SortingMode);
	}
	/**
	 * returns all the data <b>Last Names</b> sorted by the given SortingMode parameter 
	 * <b>SORT_ASCENDING</b> - will sort the data in ascending order
	 * <b>SORT_DESCENDING</b> - will sort the data in descending order
	 * <b>SORT_NONE</b> - will return unsorted data
	 */	
	public List GetLastNames(int SortingMode){
		lastNames = new ddLastNames();
		return lastNames.GetAll(SortingMode);
	}	
	/**
	 * returns all the data <b>Companies</b> sorted by the given SortingMode parameter 
	 * <b>SORT_ASCENDING</b> - will sort the data in ascending order
	 * <b>SORT_DESCENDING</b> - will sort the data in descending order
	 * <b>SORT_NONE</b> - will return unsorted data
	 */	
	public List GetCompanies(int SortingMode){
		companies = new ddCompanyNames();
		return companies.GetAll(SortingMode);
	}	
	/**
	 * returns all the data <b>Addresses</b> sorted by the given SortingMode parameter 
	 * <b>SORT_ASCENDING</b> - will sort the data in ascending order
	 * <b>SORT_DESCENDING</b> - will sort the data in descending order
	 * <b>SORT_NONE</b> - will return unsorted data
	 */	
	public List GetAddresses(int SortingMode){
		addresses = new ddAddresses();
		return addresses.GetAll(SortingMode);
	}	
	/**
	 * returns all the data <b>Cities</b> sorted by the given SortingMode parameter 
	 * <b>SORT_ASCENDING</b> - will sort the data in ascending order
	 * <b>SORT_DESCENDING</b> - will sort the data in descending order
	 * <b>SORT_NONE</b> - will return unsorted data
	 */		
	public List GetCities(int SortingMode){
		cities = new ddCities();
		return cities.GetAll(SortingMode);
	}	
	/**
	 * returns all the data <b>Countries</b> sorted by the given SortingMode parameter 
	 * <b>SORT_ASCENDING</b> - will sort the data in ascending order
	 * <b>SORT_DESCENDING</b> - will sort the data in descending order
	 * <b>SORT_NONE</b> - will return unsorted data
	 */		
	public List GetCountries(int SortingMode){
		countries = new ddCountries();
		return countries.GetAll(SortingMode);
	}
	/**
	 * returns all the data <b>Postal</b> sorted by the given SortingMode parameter 
	 * <b>SORT_ASCENDING</b> - will sort the data in ascending order
	 * <b>SORT_DESCENDING</b> - will sort the data in descending order
	 * <b>SORT_NONE</b> - will return unsorted data
	 */		
	public List GetPostal(int SortingMode){
		postal = new ddPostal();
		return postal.GetAll(SortingMode);
	}	
	/**
	 * returns all the data <b>Phones1</b> sorted by the given SortingMode parameter 
	 * <b>SORT_ASCENDING</b> - will sort the data in ascending order
	 * <b>SORT_DESCENDING</b> - will sort the data in descending order
	 * <b>SORT_NONE</b> - will return unsorted data
	 */	
	public List GetPhones1(int SortingMode){
		phones1 = new ddPhones1();
		return phones1.GetAll(SortingMode);
	}	
	/**
	 * returns all the data <b>Phones2</b> sorted by the given SortingMode parameter 
	 * <b>SORT_ASCENDING</b> - will sort the data in ascending order
	 * <b>SORT_DESCENDING</b> - will sort the data in descending order
	 * <b>SORT_NONE</b> - will return unsorted data
	 */	
	public List GetPhones2(int SortingMode){
		phones2 = new ddPhones2();
		return phones2.GetAll(SortingMode);
	}	
	/**
	 * returns all the data <b>Emails</b> sorted by the given SortingMode parameter 
	 * <b>SORT_ASCENDING</b> - will sort the data in ascending order
	 * <b>SORT_DESCENDING</b> - will sort the data in descending order
	 * <b>SORT_NONE</b> - will return unsorted data
	 */		
	public List GetEmails(int SortingMode){
		emails = new ddEmails();
		return emails.GetAll(SortingMode);
	}	
	/**
	 * returns all the data <b>Webs</b> sorted by the given SortingMode parameter 
	 * <b>SORT_ASCENDING</b> - will sort the data in ascending order
	 * <b>SORT_DESCENDING</b> - will sort the data in descending order
	 * <b>SORT_NONE</b> - will return unsorted data
	 */		
	public List GetWebs(int SortingMode){
		webs = new ddWebs();
		return webs.GetAll(SortingMode);
	}	
}
